@@ -1,9 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: DistUtil.py 13288 2021-09-01 13:04:30Z Tiffany $
+# $Id: DistUtil.py 13434 2022-04-26 09:25:17Z Jason $
 #
-# Copyright (c) 2017 Nuwa Information Co., Ltd, and individual contributors.
-# All rights reserved.
+# Copyright (c) 2022 Nuwa Information Co., Ltd, All Rights Reserved.
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
@@ -30,9 +29,9 @@
 # OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #
-# $Author: Tiffany $ (last)
-# $Date: 2021-09-01 21:04:30 +0800 (週三, 01 九月 2021) $
-# $Revision: 13288 $
+# $Author: Jason $ (last)
+# $Date: 2022-04-26 17:25:17 +0800 (Tue, 26 Apr 2022) $
+# $Revision: 13434 $
 """
 Distribution utilities.
 """
@@ -234,10 +233,7 @@ def getRequirements(requirementFile='REQUIREMENTS.txt'):
             line = f.readline()
     return requirements, extraRequirements
 
-if sys.version_info.major == 2:
-    from urllib2 import Request as urllib_request
-else:
-    import urllib.request as urllib_request
+import urllib.request as urllib_request
 
 def setup(name,
           requirementsFile="REQUIREMENTS.txt",
@@ -293,11 +289,7 @@ def setup(name,
     from setuptools import find_packages
     from pkg_resources import packaging
     
-    if packaging.version.parse(pip.__version__) >= packaging.version.parse("21.0.0"):
-        raise RuntimeError(
-            "pip version < 21.0.0 is required\n"
-            "execute 'python -m pip install pip==20.2.4' to downgrade pip"
-        )
+    
     _createManifestFile()         
     sitePackagesDir = getSitePackagesDir()   
 
@@ -390,31 +382,6 @@ def setup(name,
                    
     setuptoolsSetup(**kws)    
     
-    if 'bdist_wheel' in sys.argv:
-        print(("%s" % colored(
-            ("\n"
-             "---------------------------------------------------------"
-             "\n"
-             "Only 'sdist upload' and 'install' command will work properly."
-             "\n"
-             "\n"
-             "bdist_wheel not supported for this package. \n"
-             "If using egg install,\n"
-             "Some package would not be installed properly,\n"
-             "patch would not be executed either.\n"
-             "---------------------------------------------------------"
-             "\n"
-             "See more details: \n"
-             "https://code.nuwainfo.com/trac/mercurius/ticket/2646#comment:5"
-             "\n"
-             "https://code.nuwainfo.com/trac/mercurius/ticket/2643#comment:28"
-             "\n"
-             "https://code.nuwainfo.com/trac/Mercurius/ticket/2933#comment:25"
-             "\n"
-             "---------------------------------------------------------"
-             ), 'yellow', attrs=['bold'])
-        ))
-        raise NotImplementedError("bdist_wheel not supported for this package.")
     
     # patch
     if 'install' in sys.argv or 'bdist_wheel' in sys.argv:
