@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Json.py 13179 2021-08-04 02:15:24Z Mint $
+# $Id: Json.py 13367 2021-12-24 04:53:31Z Mint $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, and individual contributors.
 # All rights reserved.
@@ -31,8 +31,8 @@
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #
 # $Author: Mint $
-# $Date: 2021-08-04 10:15:24 +0800 (Wed, 04 Aug 2021) $
-# $Revision: 13179 $
+# $Date: 2021-12-24 12:53:31 +0800 (Fri, 24 Dec 2021) $
+# $Revision: 13367 $
 """
 JSON serializer.
 """
@@ -75,7 +75,11 @@ def datetimeFromObjDict(dic):
     return datetime.datetime(*[dic[attr] for attr in datetimeAttrs])
 
 import re
-
+# in python 3.7 or more, no longer have re._pattern_type
+# instead, there's a new name 're.Pattern'
+if not hasattr(re,'_pattern_type'):
+    re._pattern_type = re.Pattern
+    
 def regexToObjDict(obj):
     """
     Embedded JSON serailizer conversion function for regular expression type.
