@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: UtilTest.py 10960 2018-04-03 05:48:20Z Kevin $
+# $Id: UtilTest.py 13367 2021-12-24 04:53:31Z Mint $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, and individual contributors.
 # All rights reserved.
@@ -30,9 +30,9 @@
 # OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #
-# $Author: Kevin $ (last)
-# $Date: 2018-04-03 13:48:20 +0800 (週二, 03 四月 2018) $
-# $Revision: 10960 $
+# $Author: Mint $ (last)
+# $Date: 2021-12-24 12:53:31 +0800 (Fri, 24 Dec 2021) $
+# $Revision: 13367 $
 
 """
 Test all utilities.
@@ -45,6 +45,7 @@ import zipfile
 import six
 from Iuppiter import Util
 
+    
 class UtilTest(unittest.TestCase):
     """
     Test case for Util.
@@ -431,6 +432,11 @@ class UtilTest(unittest.TestCase):
             return fib(n - 1) + fib(n - 2)
 
         import time
+        # in python 3.9 there's no more time.clock().
+        # instead, a new function perf_counter() do this after python 3.7
+        if not hasattr(time,'clock'):
+            time.clock = time.perf_counter
+            
         c = time.clock()
         self.assertEqual(fib(30), 832040)
         e = time.clock() - c
